"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.designSystemComponentsRegistrationExample = exports.designSystemZeroButtonExample = exports.designSystemPrefixedButtonExample = exports.designSystemHTMLExample = exports.designSystemPrefixExample = void 0;
const color_1 = require("../color");
const component_1 = require("./component");
const general_1 = require("./general");
const designSystemPrefixExample = (prefix = 'faster') => `${color_1.Code.keyword('import')} ${color_1.Code.alias('{zeroBaseComponents, provideDesignSystem}')} ${color_1.Code.keyword('from')} ${color_1.Code.string('@genesislcap/foundation-zero')};

  ${color_1.Code.alias(`provideDesignSystem()`)}
    ${color_1.Code.alias(`.withPrefix(${color_1.Code.string(`'${prefix}'`)})`)} ${color_1.Code.lineComment(`<-- Your provided design system name. Keep it a short single word!`)}
    ${color_1.Code.alias(`.register(zeroBaseComponents);`)}
`;
exports.designSystemPrefixExample = designSystemPrefixExample;
const designSystemHTMLExample = (slotted, prefix = 'faster') => `${color_1.Code.htmlElement(`<${prefix}-design-system-provider>`)}
    ${(0, general_1.collapsedCodeIndicator)()}
    ${slotted}
    ${(0, general_1.collapsedCodeIndicator)()}
  ${color_1.Code.htmlElement(`</${prefix}-design-system-provider>`)}`;
exports.designSystemHTMLExample = designSystemHTMLExample;
const designSystemPrefixedButtonExample = (prefix = 'faster') => `${color_1.Code.htmlElement(`<${prefix}-button>`)}${color_1.Code.htmlString(`Click me!`)}${color_1.Code.htmlElement(`</${prefix}-button>`)}`;
exports.designSystemPrefixedButtonExample = designSystemPrefixedButtonExample;
const designSystemZeroButtonExample = () => `${color_1.Code.htmlElement(`<zero-button>`)}${color_1.Code.htmlString(`Click me!`)}${color_1.Code.htmlElement(`</zero-button>`)}`;
exports.designSystemZeroButtonExample = designSystemZeroButtonExample;
/**
 * Generates a design system registration code example.
 * @param components - List of component names.
 * @param prefix - The design system prefix.
 *
 * @public
 */
const designSystemComponentsRegistrationExample = (components, prefix) => {
    const uniqueComponents = [...new Set(components)];
    if (!uniqueComponents.length) {
        return;
    }
    prefix = prefix ? prefix : uniqueComponents[0].split('-')[0]; // < take prefix sample
    const output = uniqueComponents
        .sort()
        .map((componentName) => `  ${(0, component_1.componentRegisterCodeToken)(componentName)}`);
    console.log(`Please ensure these are explicitly registered with your design system, for example:

${color_1.Code.keyword('const')} {
  provideDesignSystem,
  ${prefix}DesignSystemProvider,
${[...output, null].join(`,\n`)}} = ${color_1.Code.keyword('await')} ${color_1.Code.htmlElement('designSystem')}();

provideDesignSystem().${color_1.Code.htmlElement('register')}(
  ${color_1.Code.docComment(`/**
   * Design system provider element used to declaratively apply ${prefix} config to every dom node in the host tree.
   */`)}
  ${prefix}DesignSystemProvider(),
  ${color_1.Code.docComment(`/**
   * Register your required components. You may wish to spilt up registration if some of these are only required by certain routes.
   */`)}
${[...output, null].join(`(),\n`)});`);
};
exports.designSystemComponentsRegistrationExample = designSystemComponentsRegistrationExample;
